@@ -2,22 +2,9 @@
     kmime_charfreq.h
 
     KMime, the KDE Internet mail/usenet news message library.
-    Copyright (c) 2001-2002 Marc Mutz <mutz@kde.org>
+    SPDX-FileCopyrightText: 2001-2002 Marc Mutz <mutz@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 /**
   @file
@@ -167,8 +154,8 @@ private:
     uint mTotal;       // count of all chars
     uint mLineMin;     // minimum line length
     uint mLineMax;     // maximum line length
-    bool mTrailingWS;  // does the buffer contain trailing whitespace?
-    bool mLeadingFrom; // does the buffer contain lines starting with "From "?
+    bool mTrailingWS = false;  // does the buffer contain trailing whitespace?
+    bool mLeadingFrom = false; // does the buffer contain lines starting with "From "?
     //@endcond
 
     /**
