@@ -2,23 +2,10 @@
     kmime_util.h
 
     KMime, the KDE Internet mail/usenet news message library.
-    Copyright (c) 2001 the KMime authors.
+    SPDX-FileCopyrightText: 2001 the KMime authors.
     See file AUTHORS for details
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #ifndef __KMIME_UTIL_H__
 #define __KMIME_UTIL_H__
@@ -149,6 +136,36 @@ KMIME_EXPORT extern QByteArray CRLFtoLF(const char *s);
 */
 KMIME_EXPORT extern QByteArray LFtoCRLF(const QByteArray &s);
 
+/**
+  Converts all occurrences of "\r" (CR) in @p s to "\n" (LF).
+
+  This function is expensive and should be used only if the mail
+  will be stored locally. All decode functions can cope with both
+  line endings.
+
+  @param s source string containing CR's
+
+  @return the string with CR's substitued for LF's
+  @see CRtoLF(const QByteArray&) CRtoLF
+*/
+KMIME_EXPORT extern QByteArray CRtoLF(const char *s);
+
+/**
+  Converts all occurrences of "\r" (CR) in @p s to "\n" (LF).
+
+  This function is expensive and should be used only if the mail
+  will be transmitted as an RFC822 message later. All decode
+  functions can cope with and all encode functions can optionally
+  produce both line endings, which is much faster.
+
+  @param s source string containing CR's
+
+  @return the string with CR's substitued for LF's
+  @see CRtoLF(const QByteArray&) CRtoLF
+*/
+KMIME_EXPORT extern QByteArray CRtoLF(const QByteArray &s);
+
+
 /**
   Removes quote (DQUOTE) characters and decodes "quoted-pairs"
   (ie. backslash-escaped characters)
@@ -212,7 +229,7 @@ KMIME_EXPORT extern void addQuotes(QString &str, bool forceQuotes);
  *   leading to "Firstname Lastname<RLO><PDF>", so the whole mailbox is displayed
  *   correctly as "Firstname Lastname" <moc.mitciv@attacker.com> again.
  *
- * See http://unicode.org/reports/tr9 for more information on bidi control chars.
+ * See https://unicode.org/reports/tr9 for more information on bidi control chars.
  *
  * @param input the display name of a mailbox, which is checked for unbalanced Unicode
  *              direction control characters
